/* Output validator for "Toy railway".  
 *
 * The output validator can be given a command-line argument
 * "author_messages".  If this argument is given, the validator gives
 * helpful feedback to the author of the submission.
 *
 * Note: if you start writing error messages in, say, Swedish, make
 * sure your file is UTF-8 coded.
 */
#include <utility>
#include <string>
#include <cassert>
#include <cstring>
#include <cmath>
#include "streamcorr.h"

using namespace std;
typedef long long int64;


#define MAXN 100000

int par(char s[]) {  //Parser for label in judge input
  int i,num=0;
  for(i=0;s[i]<='9';i++) num=num*10+(s[i]-'0');
  return (num-1)*3+(s[i]-'A');
}


bool author_messages = true;

/* Wrapper for author message printing so that they are only printed in
 * case the author_messages option was given.  If the validator should
 * always print author messages, you can just call
 * report_feedback(authormessage, ...) directly.
 */
void author_message(const char *s) {
  if (author_messages) {
    report_feedback(authormessage, s);
  }
}


int run(char ans[], int N, int con[]) {
  int d[MAXN*3],i,k;
  if(strcmp(ans,"Impossible")==0) return 0;
  //Has the answer correct format?
  if(strlen(ans)!=N) return -2;
  for(i=0;i<N;i++) if(ans[i]!='B' && ans[i]!='C') return -3;
  //Now start the train and see where it goes.
  for(i=0;i<3*N;i++) d[i]=0;
  i=0; k=0;
  do {
    d[i]=1;
    if(i%3==0) i=con[i+ans[i/3]-'A'];
    else i=con[i-(i%3)];
    k++;
  } while(i>0 && d[i]==0);
  return (i==0) ? k : -1;    //Return loop length, or -1 if train has not returned.
}


bool check_case() {
  int N, T,i,ns,ts,ans_ns,ans_ts,ntr,sum;
  int t[1000],m[1000];

  if (!(judge_in >> N >> T))
    judge_error("Error reading input file. 1");
  for(i=0;i<N;i++) {
    if (!(judge_in >> t[i]))
      judge_error("Error reading input file.");
  }
  if (!(judge_ans >> ans_ts >> ans_ns))
    judge_error("Error reading answer file.");
  if (!(author_out >> ts >> ns)) {
    author_message("Bad format");
    report_error("Bad format");
  }
  for(i=0;i<N;i++) {
    if (!(author_out >> m[i])) {
      author_message("Bad format");
      report_error("Bad format");
    }
  }
  if(ts!=ans_ts) {
    author_message("Wrong time");
    report_error("Wrong time");
  }
  if(ns!=ans_ns) {
    author_message("Wrong number of tracks");
    report_error("Wrong number of tracks");
  }
  sum=0; ntr=0;
  for(i=0;i<N;i++) {
    sum+=m[i];
    if((m[i]!=0 && m[i]<t[i]) || ((m[i] % (t[i]/2) != 0))) {
      author_message("Illegal time spent on track");
      report_error("Illegal time spent on track");
    }
    ntr+= (m[i]+t[i]/2)/t[i];
  }
  if(sum!=ts || ntr!=ns) {
    author_message("Inconsistent output");
    report_error("Inconsistent output");
  }
  return true;  // Correct answer
}

int main(int argc, char **argv) {
  init_io(argc, argv);
  /* Check if the author_messages option is given. */
  for (int i = 4; i < argc; ++i)
    if (!strcmp(argv[i], "author_messages"))
      author_messages = true;

  check_case();

  /* Yay! */
  author_message("Thank you for your great code.  It was fantastic.");
  accept();
}
